==> freecad_0.18.3+dfsg1.orig.tar.xz: FreeCAD-0.18.3/src/Mod/Tux/Resources/translations/Tux_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>Escolmar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>Zoom</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>Xirar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>Panorámica</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>Inclinar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>Estilo de Navegación</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>Tecla Page Up ou Page Down.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>Foco de rotación</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>Botón central do rato.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>Estilo de navegación non recoñecido.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Axustes</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Estilo orbital</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Compacto</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Suxestión</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Plataforma xiratoria</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>Indeterminado</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or H key.</source>
      <translation>Botón central do rato ou tecla H.</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Tux/Resources/translations/Tux_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="gl" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="NavigationIndicatorGui.py" line="63"/>
      <source>Select</source>
      <translation>Escolmar</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="64"/>
      <source>Zoom</source>
      <translation>Zoom</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="65"/>
      <source>Rotate</source>
      <translation>Xirar</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="66"/>
      <source>Pan</source>
      <translation>Panorámica</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="67"/>
      <source>Tilt</source>
      <translation>Inclinar</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="68"/>
      <source>Navigation style</source>
      <translation>Estilo de Navegación</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="69"/>
      <source>Page Up or Page Down key.</source>
      <translation>Tecla Page Up ou Page Down.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="70"/>
      <source>Rotation focus</source>
      <translation>Foco de rotación</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="73"/>
      <source>Middle mouse button.</source>
      <translation>Botón central do rato.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="76"/>
      <source>Navigation style not recognized.</source>
      <translation>Estilo de navegación non recoñecido.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Axustes</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Estilo orbital</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Compacto</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Suxestión</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Plataforma xiratoria</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>Indeterminado</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button or H key.</source>
      <translation>Botón central do rato ou tecla H.</translation>
    </message>
  </context>
</TS>
